/*********************************************************************
 * Job Ticket API (JTAPI) fsgjt_enums.h                                           
 *                                                                   
 * Copyright (c) 2004 High North Inc.                                                                  
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.         
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.          
 *
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS COMMON 
 * PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION 
 * OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *********************************************************************/
#ifndef FSGJT_ENUMS_H
#define FSGJT_ENUMS_H

/************************************************************
 * For the JTAPI alpha version only the following 
 * enumerations are supported:
 *      InputTrayNameEnum
 *      JobTicketTypeVersionEnum
 *      LengthUnitEnum
 *      MediaTypeEnum
 *      PrintQualityEnum
 *      RotationEnum
 *      SidesEnum
 *      StitchTypeEnum 
 *      ValueTypeEnum 
 ***********************************************************/

/************************************************************
 * BindTypeEnum
 *
 * Whether or not to bind and what kind of binding to use.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_BD_NOT_SET = 0,
   FSGJT_BD_NONE,
   FSGJT_BD_CHANNEL,
   FSGJT_BD_EDGE_GLUE,
   FSGJT_BD_PERFECT,
   FSGJT_BD_PLASTIC_COMB,
   FSGJT_BD_RING,
   FSGJT_BD_SPIRAL,
   FSGJT_BD_STRIP,
   FSGJT_BD_TAPE,
   FSGJT_BD_THREAD_SEAL,
   FSGJT_BD_VELO,
   FSGJT_BD_WIRE_COMB
} fsgjt_bind_type_t;

/************************************************************
 * BooleanEnum
 *
 * Boolean true or false.
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_BL_FALSE = 0,
   FSGJT_BL_TRUE
} fsgjt_boolean_t;

/************************************************************
 * CollateEnum
 *
 * Whether the sheets and/or documents are to be collated or 
 * not.
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_CL_NOT_SET = 0,
   FSGJT_CL_NONE,
   FSGJT_CL_SHEET,
   FSGJT_CL_SHEET_AND_DOC
} fsgjt_collate_t;

/************************************************************
 * CompressionEnum
 *
 * Type of compression algorithm to use for the data 
 * contained in the document.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_CM_NOT_SET = 0,
   FSGJT_CM_NONE,
   FSGJT_CM_COMPRESS,
   FSGJT_CM_DEFLATE, 
   FSGJT_CM_GZIP
} fsgjt_compression_t;

/************************************************************
 * ContactTypeEnum
 *
 * Role of the person that is to be contacted regarding the
 * job.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_CT_NOT_SET = 0,
   FSGJT_CT_ACCOUNTING,
   FSGJT_CT_ADMINISTRATOR,
   FSGJT_CT_APPROVER,
   FSGJT_CT_ART_RETURN,
   FSGJT_CT_CUSTOMER,
   FSGJT_CT_DELIVERY,
   FSGJT_CT_PICKUP,
   FSGJT_CT_SENDER,
   FSGJT_CT_SUPPLIER,
   FSGJT_CT_SURPLUS_RETURN
} fsgjt_contact_type_t;

/************************************************************
 * FeedOrientationEnum
 * 
 * The orientation of the media as it is to be fed into the
 * device.
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_FO_NOT_SET = 0,
   FSGJT_FO_LONG_EDGE_FIRST,
   FSGJT_FO_SHORT_EDGE_FIRST
} fsgjt_feed_orientation_t;

/************************************************************
 * FitPolicyEnum
 * 
 * How to modify the content to fit on the media.
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_FP_NOT_SET = 0,
   FSGJT_FP_CLIP_TO_PAGE,
   FSGJT_FP_FIT_TO_PAGE,
   FSGJT_FP_ROTATE_AND_OR_FIT
} fsgjt_fit_policy_t;

/************************************************************
 * FoldTypeEnum
 *
 * The type of folding to perform.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{ 
   FSGJT_FD_NOT_SET = 0,
   FSGJT_FD_NONE,
   FSGJT_FD_C,
   FSGJT_FD_SADDLE,
   FSGJT_FD_Z,
   FSGJT_FD_Z_IN_THIRDS
} fsgjt_fold_type_t;

/************************************************************
 * HoldEnum
 *
 * Whether or not to hold the job and for how long.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_HD_NOT_SET = 0,
   FSGJT_HD_INDEFINITE,
   FSGJT_HD_NO_HOLD
} fsgjt_hold_t;

/************************************************************
 * ImageAlignmentXEnum
 *
 * How to align the image in the x direction.
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_IAX_NOT_SET = 0,
   FSGJT_IAX_NONE,
   FSGJT_IAX_CENTER,
   FSGJT_IAX_LEFT,
   FSGJT_IAX_RIGHT
} fsgjt_image_alignment_x_t;

/************************************************************
 * ImageAlignmentYEnum
 *
 * How to align the image in the y direction. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_IAY_NOT_SET = 0,
   FSGJT_IAY_NONE,
   FSGJT_IAY_BOTTOM,
   FSGJT_IAY_CENTER,
   FSGJT_IAY_TOP 
} fsgjt_image_alignment_y_t;

/************************************************************
 * InputTrayNameEnum
 *
 * Names of the input trays.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_IT_NOT_SET = 0,
   FSGJT_IT_ANY_SMALL_FORMAT,
   FSGJT_IT_ANY_LARGE_FORMAT,
   FSGJT_IT_AUTO_SELECT,
   FSGJT_IT_BOTTOM,
   FSGJT_IT_BYPASS_TRAY,
   FSGJT_IT_BYPASS_TRAY_1,
   FSGJT_IT_BYPASS_TRAY_2,
   FSGJT_IT_BYPASS_TRAY_3,
   FSGJT_IT_CONTINUOUS,
   FSGJT_IT_DISC,
   FSGJT_IT_DISC_1, 
   FSGJT_IT_DISC_2,
   FSGJT_IT_DISC_3,        
   FSGJT_IT_ENVELOPE,
   FSGJT_IT_ENVELOPE_1,
   FSGJT_IT_ENVELOPE_2,
   FSGJT_IT_ENVELOPE_3,
   FSGJT_IT_FRONT,
   FSGJT_IT_INSERT_TRAY,
   FSGJT_IT_INSERT_TRAY_1,
   FSGJT_IT_INSERT_TRAY_2,
   FSGJT_IT_INSERT_TRAY_3,
   FSGJT_IT_LARGE_CAPACITY,
   FSGJT_IT_LARGE_CAPACITY_1,
   FSGJT_IT_LARGE_CAPACITY_2,
   FSGJT_IT_LARGE_CAPACITY_3,
   FSGJT_IT_LEFT,
   FSGJT_IT_MIDDLE,
   FSGJT_IT_REAR,
   FSGJT_IT_RIGHT,
   FSGJT_IT_ROLL,
   FSGJT_IT_ROLL_1,
   FSGJT_IT_ROLL_2,
   FSGJT_IT_ROLL_3,
   FSGJT_IT_SIDE,
   FSGJT_IT_TOP,
   FSGJT_IT_TRAY,
   FSGJT_IT_TRAY_1,
   FSGJT_IT_TRAY_2,
   FSGJT_IT_TRAY_3
} fsgjt_input_tray_name_t;

/************************************************************
 * InsertSheetContentEnum
 *
 * What is to appear on the insert sheet. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_IC_NOT_SET = 0,
   FSGJT_IC_BLANK,
   FSGJT_IC_DUPLICATE
} fsgjt_insert_sheet_content_t;

/************************************************************
 * JobTicketTypeVersionEnum
 *
 * Type and version of the job ticket syntax.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_JT_NOT_SET = 0,
   FSGJT_JT_AUTO_DETECT,
   FSGJT_JT_JDF_1_2,
   FSGJT_JT_OTHER,
   FSGJT_JT_PWG
} fsgjt_job_ticket_type_version_t;

/************************************************************
 * JogOffsetEnum
 *
 * Whether or not the job and job copies are to be offset 
 * stacked. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_JO_NOT_SET = 0,
   FSGJT_JO_NONE,
   FSGJT_JO_ALTERNATE
} fsgjt_jog_offset_t;


/************************************************************
 * LengthUnitEnum
 *
 * Unit if measure to use when specifying length. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_LU_NOT_SET = 0,
   FSGJT_LU_MICROMETERS,
   FSGJT_LU_POINTS,
   FSGJT_LU_TEN_THOUSANDTHS_OF_INCHES
} fsgjt_length_unit_t;

/************************************************************
 * MandatoryAtributesEnum
 *
 * Attributes that are mandatory and must be supported.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_MA_NOT_SET = 0,
   FSGJT_MA_NONE,
   FSGJT_MA_ALL,
} fsgjt_mandatory_attributes_t;

/************************************************************
 * MediaCoatingEnum
 *
 * Type of coating on the media. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_MG_NOT_SET = 0,
   FSGJT_MG_NONE,
   FSGJT_MG_COATED,
   FSGJT_MG_GLOSSY,
   FSGJT_MG_HIGH_GLOSS,
   FSGJT_MG_INK_JET,
   FSGJT_MG_MATTE,
   FSGJT_MG_SATIN,
   FSGJT_MG_SEMI_GLOSS
} fsgjt_media_coating_t;

/************************************************************
 * MediaColorEnum
 *
 * Color of the media. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_MC_NOT_SET = 0,
   FSGJT_MC_BLACK,
   FSGJT_MC_CLEAR_BLACK,
   FSGJT_MC_DARK_BLACK, 
   FSGJT_MC_LIGHT_BLACK,
   FSGJT_MC_BLUE, 
   FSGJT_MC_CLEAR_BLUE,
   FSGJT_MC_DARK_BLUE,
   FSGJT_MC_LIGHT_BLUE,
   FSGJT_MC_BROWN,
   FSGJT_MC_CLEAR_BROWN,
   FSGJT_MC_DARK_BROWN,
   FSGJT_MC_LIGHT_BROWN,
   FSGJT_MC_BUFF,
   FSGJT_MC_CLEAR_BUFF,
   FSGJT_MC_DARK_BUFF,
   FSGJT_MC_LIGHT_BUFF,
   FSGJT_MC_CYAN,
   FSGJT_MC_CLEAR_CYAN,        
   FSGJT_MC_DARK_CYAN,
   FSGJT_MC_LIGHT_CYAN,
   FSGJT_MC_GOLD,
   FSGJT_MC_CLEAR_GOLD,
   FSGJT_MC_DARK_GOLD,
   FSGJT_MC_LIGHT_GOLD,
   FSGJT_MC_GOLDENROD,
   FSGJT_MC_CLEAR_GODLENROD,
   FSGJT_MC_DARK_GOLDENROD,
   FSGJT_MC_LIGHT_GOLDENROD,
   FSGJT_MC_GRAY,
   FSGJT_MC_CLEAR_GRAY,
   FSGJT_MC_DARK_GRAY,
   FSGJT_MC_LIGHT_GRAY,
   FSGJT_MC_GREEN,
   FSGJT_MC_CLEAR_GREEN,
   FSGJT_MC_DARK_GREEN,
   FSGJT_MC_LIGHT_GREEN,
   FSGJT_MC_IVORY,
   FSGJT_MC_CLEAR_IVORY,
   FSGJT_MC_DARK_IVORY,
   FSGJT_MC_LIGHT_IVORY,
   FSGJT_MC_MAGENTA,
   FSGJT_MC_CLEAR_MAGENTA,
   FSGJT_MC_DARK_MAGENTA,
   FSGJT_MC_LIGHT_MAGENTA,
   FSGJT_MC_MULTI_COLOR,
   FSGJT_MC_CLEAR_MULTI_COLOR,
   FSGJT_MC_DARK_MULTI_COLOR,
   FSGJT_MC_LIGHT_MULTI_COLOR,
   FSGJT_MC_MUSTARD,
   FSGJT_MC_CLEAR_MUSTARD,
   FSGJT_MC_DARK_MUSTARD,
   FSGJT_MC_LIGHT_MUSTARD,
   FSGJT_MC_NO_COLOR,
   FSGJT_MC_CLEAR_NO_COLOR,
   FSGJT_MC_DARK_NO_COLOR,
   FSGJT_MC_LIGHT_NO_COLOR,
   FSGJT_MC_ORANGE,
   FSGJT_MC_CLEAR_ORANGE,
   FSGJT_MC_DARK_ORANGE,
   FSGJT_MC_LIGHT_ORANGE,
   FSGJT_MC_PINK,
   FSGJT_MC_CLEAR_PINK,
   FSGJT_MC_DARK_PINK,
   FSGJT_MC_LIGHT_PINK,
   FSGJT_MC_RED,
   FSGJT_MC_CLEAR_RED,
   FSGJT_MC_DARK_RED,
   FSGJT_MC_LIGHT_RED,
   FSGJT_MC_SILVER,
   FSGJT_MC_CLEAR_SILVER,
   FSGJT_MC_DARK_SILVER,
   FSGJT_MC_LIGHT_SILVER,
   FSGJT_MC_TURQUOISE,
   FSGJT_MC_CLEAR_TURQUOISE,
   FSGJT_MC_DARK_TURQUOISE,
   FSGJT_MC_LIGHT_TURQUOISE,
   FSGJT_MC_VIOLET,
   FSGJT_MC_CLEAR_VIOLET,
   FSGJT_MC_DARK_VIOLET,
   FSGJT_MC_LIGHT_VIOLET,
   FSGJT_MC_WHITE,
   FSGJT_MC_CLEAR_WHITE,
   FSGJT_MC_DARK_WHITE,
   FSGJT_MC_LIGHT_WHITE,
   FSGJT_MC_YELLOW,
   FSGJT_MC_CLEAR_YELLOW,
   FSGJT_MC_DARK_YELLOW,
   FSGJT_MC_LIGHT_YELLOW
} fsgjt_media_color_t;

/************************************************************
 * MediaTypeEnum
 *
 * Type of the media.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_MT_NOT_SET = 0,
   FSGJT_MT_CARD_STOCK,
   FSGJT_MT_CONTINUOUS,
   FSGJT_MT_CONTINUOUS_LONG,
   FSGJT_MT_CONTINUOUS_SHORT, 
   FSGJT_MT_DISC,
   FSGJT_MT_ENVELOPE,
   FSGJT_MT_ENVELOPE_PLAIN,
   FSGJT_MT_ENVELOPE_WINDOW,
   FSGJT_MT_FILM_PHOTOGRAPHIC,
   FSGJT_MT_FILM_BLACK_PRINT,
   FSGJT_MT_FULL_CUT_TABS,
   FSGJT_MT_LABELS,
   FSGJT_MT_MULTI_LAYER,
   FSGJT_MT_MULTI_PART_FORMS,
   FSGJT_MT_PHOTOGRAPHIC,
   FSGJT_MT_PRE_CUT_TABS,
   FSGJT_MT_ROLL, 
   FSGJT_MT_STATIONERY,
   FSGJT_MT_TAB_STOCK,
   FSGJT_MT_TRANSPARENCY
} fsgjt_media_type_t;

/************************************************************
 * OutputBinEnum
 *
 * Names of output bins.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_OB_NOT_SET = 0,
   FSGJT_OB_BOOKLET,
   FSGJT_OB_BOTTOM,
   FSGJT_OB_CENTER,
   FSGJT_OB_FACE_DOWN,
   FSGJT_OB_FACE_UP,
   FSGJT_OB_FIT_MEDIA,
   FSGJT_OB_LARGE_CAPACITY,
   FSGJT_OB_LEFT,
   FSGJT_OB_MAILBOX_1,
   FSGJT_OB_MAILBOX_2,
   FSGJT_OB_MAILBOX_3,
   FSGJT_OB_MIDDLE,
   FSGJT_OB_MY_MAILBOX,
   FSGJT_OB_REAR,
   FSGJT_OB_RIGHT,
   FSGJT_OB_SIDE,
   FSGJT_OB_STACKER_1,
   FSGJT_OB_STACKER_2,
   FSGJT_OB_STACKER_3,
   FSGJT_OB_TOP,
   FSGJT_OB_TRAY_1,
   FSGJT_OB_TRAY_2,
   FSGJT_OB_TRAY_3
} fsgjt_output_bin_t;

/************************************************************
 * PageDeliveryEnum
 *
 * How the pages are to be ordered when output. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PD_NOT_SET = 0,
   FSGJT_PD_FAN_FOLD,
   FSGJT_PD_REVERSE_ORDER_FACE_DOWN,
   FSGJT_PD_REVERSE_ORDER_FACE_UP,
   FSGJT_PD_SAME_ORDER_FACE_DOWN,
   FSGJT_PD_SAME_ORDER_FACE_UP
} fsgjt_page_delivery_t;

/************************************************************
 * PositionEnum
 *
 * Position from which the operation is to occur. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PS_NOT_SET = 0,
   FSGJT_PS_AFTER,
   FSGJT_PS_BEFORE
} fsgjt_position_t;

/************************************************************
 * PreprintedEnum
 *
 * Whether or not the media is preprinted.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PP_NOT_SET = 0,
   FSGJT_PP_BLANK,
   FSGJT_PP_LETTERHEAD,
   FSGJT_PP_PREPRINTED
} fsgjt_preprinted_t;

/************************************************************ 
 * PresentEnum 
 *
 * Used to describe the presence of the value and if present
 * whether the value is on or off.
 * 
 * Extensible 
 ***********************************************************/
typedef enum
{
   FSGJT_PT_NOT_SET = 0,
   FSGJT_PT_OFF,
   FSGJT_PT_ON
} fsgjt_present_t;

/* The following is what we originally defined:
typedef fsgjt_int32_t fsgjt_present_t;
#define FSGJT_ON           1
#define FSGJT_OFF          0
#define FSGJT_NOT_PRESENT -1
*/

/************************************************************
 * PresentationDirectionEnum
 *
 * Placement order of the pages. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PR_NOT_SET = 0,
   FSGJT_PR_TO_RIGHT_TO_BOTTOM,
   FSGJT_PR_TO_BOTTOM_TO_RIGHT,
   FSGJT_PR_TO_LEFT_TO_BOTTOM,
   FSGJT_PR_TO_BOTTOM_TO_LEFT,
   FSGJT_PR_TO_RIGHT_TO_TOP,
   FSGJT_PR_TO_TOP_TO_RIGHT,
   FSGJT_PR_TO_LEFT_TO_TOP,
   FSGJT_PR_TO_TOP_TO_LEFT
} fsgjt_presentation_direction_t;

/************************************************************
 * PrintContentOptimizeEnum
 *
 * What to optimize when printing. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PC_NOT_SET = 0,
   FSGJT_PC_GRAPHICS,  
   FSGJT_PC_PHOTO,  
   FSGJT_PC_TEXT,
   FSGJT_PC_TEXT_AND_GRAPHICS
} fsgjt_print_content_optimize_t;

/************************************************************
 * PrintQualityEnum
 *
 * The quality of the print to produce. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_PQ_NOT_SET = 0,
   FSGJT_PQ_DRAFT,  
   FSGJT_PQ_HIGH,  
   FSGJT_PQ_NORMAL
} fsgjt_print_quality_t;

/************************************************************
 * ReferenceEdgeEnum
 *
 * Reference edge from where the operation is to occur. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_RE_NOT_SET = 0,
   FSGJT_RE_BOTTOM,  
   FSGJT_RE_LEFT,  
   FSGJT_RE_RIGHT,
   FSGJT_RE_TOP
} fsgjt_reference_edge_t;

/************************************************************
 * RotationEnum
 *
 * How much to rotate an image. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_RT_NOT_SET = 0,
   FSGJT_RT_0_DEGREES,
   FSGJT_RT_90_DEGREES,
   FSGJT_RT_180_DEGREES,
   FSGJT_RT_270_DEGREES
} fsgjt_rotation_t;

/************************************************************
 * SeparatorSheetEnum
 *
 * Type of start, separator/slip, end sheets to include 
 * with the job. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_SS_NOT_SET = 0,
   FSGJT_SS_AFTER_DOC_COPIES,
   FSGJT_SS_AFTER_JOB,
   FSGJT_SS_BEFORE_DOC_COPIES,
   FSGJT_SS_BEFORE_JOB,
   FSGJT_SS_BETWEEN_DOC_COPIES,
   FSGJT_SS_BETWEEN_JOB_COPIES
} fsgjt_separator_sheet_t;

/************************************************************
 * SheetSideEnum
 *
 * Side of the sheet to image on. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_SI_NOT_SET = 0,
   FSGJT_SI_BACK_SIDE,
   FSGJT_SI_FRONT_SIDE
} fsgjt_sheet_side_t;

/************************************************************
 * SidesEnum
 *
 * Sides to image on. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_SD_NOT_SET = 0,
   FSGJT_SD_ONE_SIDED_FRONT,
   FSGJT_SD_ONE_SIDED_LONG_EDGE_BACK,
   FSGJT_SD_ONE_SIDED_SHORT_EDGE_BACK,
   FSGJT_SD_TWO_SIDED_LONG_EDGE,
   FSGJT_SD_TWO_SIDED_SHORT_EDGE
} fsgjt_sides_t;

/************************************************************
 * StitchTypeEnum
 *
 * Whether or not to stitch and where to place the stitch. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_ST_NOT_SET = 0,
   FSGJT_ST_NONE,
   FSGJT_ST_CORNER,
   FSGJT_ST_SADDLE,
   FSGJT_ST_SIDE
} fsgjt_stitch_type_t;

/************************************************************
 * SubscriptionEventEnum
 *
 * Events to subscribe for.
 * 
 * Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_SE_NOT_SET = 0,
   FSGJT_SE_JOB_CREATED,
   FSGJT_SE_JOB_COMPLETED,
   FSGJT_SE_JOB_STOPPED,
   FSGJT_SE_JOB_PROGRESS,
   FSGJT_SE_JOB_CONFIG_CHANGED,
   FSGJT_SE_JOB_STATE_CHANGED
} fsgjt_subscription_event_t;

/************************************************************
 * TrimTypeEnum
 *
 * Whether or not to trim pages. 
 * 
 * Not Extensible
 ***********************************************************/
typedef enum
{
   FSGJT_TR_NOT_SET = 0,
   FSGJT_TR_NONE,
   FSGJT_TR_FACE,
   FSGJT_TR_GUTTER,
   FSGJT_TR_TAB,
   FSGJT_TR_TRIM
} fsgjt_trim_type_t;

/************************************************************
 * Value Types
 *
 * The type of an attribute's value(s).
 * 
 * Extensible
 ***********************************************************/
#define FSGJT_VT_NOT_SET                   "NOT_SET"                                            
#define FSGJT_VT_BIND_TYPE_ENUM            "BIND_TYPE_ENUM"
#define FSGJT_VT_BINDING_OBJECT            "BINDING_OBJECT"
#define FSGJT_VT_BOOLEAN_ENUM              "BOOLEAN_ENUM"
#define FSGJT_VT_COLLATE_ENUM              "COLLATE_ENUM"
#define FSGJT_VT_COMPRESSION_ENUM          "COMPRESSION_ENUM"
#define FSGJT_VT_CONTACT_INFO_OBJECT       "CONTACT_INFO_OBJECT"
#define FSGJT_VT_CONTACT_TYPE_ENUM         "CONTACT_TYPE_ENUM"
#define FSGJT_VT_DATE_TIME_OBJECT          "DATE_TIME_OBJECT"
#define FSGJT_VT_DESTINATION_OBJECT        "DESTINATION_OBJECT"
#define FSGJT_VT_DOCUMENT_OBJECT           "DOCUMENT_OBJECT"
#define FSGJT_VT_DOUBLE                    "DOUBLE"
#define FSGJT_VT_FEED_ORIENTATION_ENUM     "FEED_ORIENTATION_ENUM"
#define FSGJT_VT_FIT_POLICY_ENUM           "FIT_POLICY_ENUM"
#define FSGJT_VT_FOLDING_OBJECT            "FOLDING_OBJECT"
#define FSGJT_VT_FOLD_TYPE_ENUM            "FOLD_TYPE_ENUM"
#define FSGJT_VT_FORCE_PAGE_OBJECT         "FORCE_PAGE_OBJECT"
#define FSGJT_VT_HOLD_ENUM                 "HOLD_ENUM"
#define FSGJT_VT_HOLE_MAKING_OBJECT        "HOLE_MAKING_OBJECT"
#define FSGJT_VT_IMAGE_ALIGNMENT_X_ENUM    "IMAGE_ALIGNMENT_X_ENUM"
#define FSGJT_VT_IMAGE_ALIGNMENT_Y_ENUM    "IMAGE_ALIGNMENT_Y_ENUM"
#define FSGJT_VT_INPUT_TRAY_NAME_ENUM      "INPUT_TRAY_NAME_ENUM"
#define FSGJT_VT_INSERT_SHEET_OBJECT       "INSERT_SHEET"
#define FSGJT_VT_INSERT_SHEET_CONTENT_ENUM "INSERT_SHEET_CONTENT_ENUM"
#define FSGJT_VT_INTEGER                   "INTEGER"
#define FSGJT_VT_JOB_OBJECT                "JOB_OBJECT"
#define FSGJT_VT_JOB_TICKET_INFO_OBJECT    "JOB_TICKET_INFO_OBJECT"
#define FSGJT_VT_JOB_TICKET_TYPE_VERSION_ENUM "JOB_TICKET_TYPE_VERSION_ENUM"
#define FSGJT_VT_JOG_OFFSET_ENUM           "JOG_OFFSET_ENUM"
#define FSGJT_VT_LENGTH_UNIT_ENUM          "LENGTH_UNIT_ENUM"
#define FSGJT_VT_MANDATORY_ATTRIBUTES_ENUM "MANDATORY_ATTRIBUTES_ENUM"
#define FSGJT_VT_MEDIA_OBJECT              "MEDIA_OBJECT"
#define FSGJT_VT_MEDIA_COATING_ENUM        "MEDIA_COATING_ENUM"
#define FSGJT_VT_MEDIA_COLOR_ENUM          "MEDIA_COLOR_ENUM"
#define FSGJT_VT_MEDIA_TYPE_ENUM           "MEDIA_TYPE_ENUM"
#define FSGJT_VT_MIME_TYPE                 "MIME_TYPE"
#define FSGJT_VT_OUTPUT_BIN_ENUM           "OUTPUT_BIN_ENUM"
#define FSGJT_VT_PAGE_DELIVERY_ENUM        "PAGE_DELIVERY_ENUM"
#define FSGJT_VT_PAGE_OVERRIDES            "PAGE_OVERRIDES"
#define FSGJT_VT_PAGE_RANGE_OBJECT         "PAGE_RANGE_OBJECT"
#define FSGJT_VT_POSITION_ENUM             "POSITION_ENUM"
#define FSGJT_VT_PREPRINTED_ENUM           "PREPRINTED_ENUM"
#define FSGJT_VT_PRESENT_ENUM              "PRESENT_ENUM"
#define FSGJT_VT_PRESENTATION_DIRECTION_ENUM "PRESENTATION_DIRECTION_ENUM"
#define FSGJT_VT_PRINT_CONTENT_OPTIMIZE_ENUM "PRINT_CONTENT_OPTIMIZE_ENUM"
#define FSGJT_VT_PRINT_QUALITY_ENUM        "PRINT_QUALITY_ENUM"
#define FSGJT_VT_REFERENCE_EDGE_ENUM       "REFERENCE_EDGE_ENUM"
#define FSGJT_VT_ROTATION_ENUM             "ROTATION_ENUM"
#define FSGJT_VT_SEPARATOR_SHEET_OBJECT    "SEPARATOR_SHEET_OBJECT"
#define FSGJT_VT_SEPARATOR_SHEET_ENUM      "SEPARATOR_SHEET_ENUM"
#define FSGJT_VT_SHEET_SIDE_ENUM           "SHEET_SIDE_ENUM"  
#define FSGJT_VT_SIDES_ENUM                "SIDES_ENUM"
#define FSGJT_VT_SIZE_NAME                 "SIZE_NAME"
#define FSGJT_VT_STITCHING_OBJECT          "STITCHING_OBJECT"
#define FSGJT_VT_STITCH_TYPE_ENUM          "STITCH_TYPE_ENUM"
#define FSGJT_VT_STRING                    "STRING"
#define FSGJT_VT_SUBSCRIPTION_OBJECT       "SUBSCRIPTION_OBJECT"
#define FSGJT_VT_SUBSCRIPTION_EVENT_ENUM   "SUBSCRIPTION_EVENT_ENUM"
#define FSGJT_VT_TRIMMING_OBJECT           "TRIMMING_OBJECT"
#define FSGJT_VT_TRIM_TYPE_ENUM            "TRIM_TYPE_ENUM"

#endif /* FSGJT_ENUMS_H */
